@@ -6,7 +6,7 @@ from xlsx_lib.domain.frame.element_part import ElementPart
 
 
 class FrameElement(CamelModel):
-    name: str
+    name: Optional[str]
     value: Optional[str]
     observations: Optional[Union[str, List[str]]]
     element_parts: Optional[List[ElementPart]]
