@@ -5,6 +5,7 @@ from openpyxl.cell import Cell
 from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl_image_loader import SheetImageLoader
 
+from domain.shared.text_line import TextLine
 from xlsx_lib.domain.distribution.new_distribution_image import NewImage
 from xlsx_lib.domain.smart_key.Fault import Fault
 from xlsx_lib.domain.smart_key.SmartKeyCellValueKind import SmartKeyCellValueKind
@@ -28,6 +29,7 @@ class SmartKeySheet(Sheet):
     ):
         self.smart_key_data: SmartKeyData = SmartKeyData()
         self.stored_flashs_number_by_time: List[str] = []
+        self.stored_parts_to_review: List[str] = []
 
         self.smart_key_images: List[NewImage] = []
 
@@ -72,7 +74,7 @@ class SmartKeySheet(Sheet):
             row_index += 1
 
     def process_cell(self, cell: Cell, col_index: int, row_index: int):
-        if cell.value is None and self.sheet_reader.read_cell_value(row=row_index, col=col_index+2) is None:
+        if cell.value is None and self.sheet_reader.read_cell_value(row=row_index, col=col_index+3) is None:
             self.check_next_values(row=row_index)
             raise ContinueException
 
@@ -88,7 +90,7 @@ class SmartKeySheet(Sheet):
     ) -> None:
         values: List[str] = self.sheet_reader.read_cells_values(
             col,
-            col + 2,
+            col + 3,
             row,
             row
         )
@@ -96,19 +98,20 @@ class SmartKeySheet(Sheet):
         if values[0] is not None:
             if self.sheet_reader.read_cell_value(row=row-1, col=col) is not None:
 
-                if self.smart_key_data.faults_list[-1].fault_kind[-1][-1] == " ":
-                    self.smart_key_data.faults_list[-1].fault_kind[-1] += " "
+                if self.smart_key_data.faults_list[-1].fault_kind[-1].text[-1] == " ":
+                    self.smart_key_data.faults_list[-1].fault_kind[-1].text += " "
 
-                self.smart_key_data.faults_list[-1].fault_kind[-1] += f" {values[0]}"
+                self.smart_key_data.faults_list[-1].fault_kind[-1].text += f" {values[0]}"
 
             elif self.sheet_reader.read_cell_value(row=row-2, col=col) is not None:
-                self.smart_key_data.faults_list[-1].fault_kind.append(values[0])
+                self.smart_key_data.faults_list[-1].fault_kind.append(TextLine(text=values[0]))
 
             else:
                 self.smart_key_data.faults_list.append(
                     Fault(
-                        fault_kind=[values[0]],
-                        flashs_number_by_time=self.stored_flashs_number_by_time.pop() if len(self.stored_flashs_number_by_time) != 0 else None
+                        fault_kind=[TextLine(text=values[0])],
+                        flashs_number_by_time=self.stored_flashs_number_by_time.pop() if len(self.stored_flashs_number_by_time) != 0 else None,
+                        parts_to_review=[TextLine(text=self.stored_parts_to_review.pop())] if len(self.stored_parts_to_review) != 0 else None
                     )
                 )
 
@@ -127,6 +130,25 @@ class SmartKeySheet(Sheet):
                 else:
                     self.stored_flashs_number_by_time.append(values[2])
 
+        if values[3] is not None:
+            previous_row_value = self.sheet_reader.read_cell_value(row=row-1, col=col+3)
+
+            if previous_row_value is None:
+                if self.smart_key_data.faults_list[-1].parts_to_review is None:
+                    self.smart_key_data.faults_list[-1].parts_to_review = [TextLine(text=values[3])]
+                elif self.sheet_reader.read_cell_value(row=row - 2, col=col + 3) is None:
+                    self.stored_parts_to_review.append(values[3])
+                else:
+                    self.smart_key_data.faults_list[-1].parts_to_review.append(TextLine(text=values[3]))
+
+            else:
+                if previous_row_value.startswith("REVISAR") and values[3].startswith("REVISAR"):
+                    self.smart_key_data.faults_list[-1].parts_to_review.append(TextLine(text=values[3]))
+                elif self.smart_key_data.faults_list[-1].parts_to_review is not None:
+                    if self.smart_key_data.faults_list[-1].parts_to_review[-1].text[-1] == " ":
+                        self.smart_key_data.faults_list[-1].parts_to_review[-1].text += " "
+                    self.smart_key_data.faults_list[-1].parts_to_review[-1].text += f" {values[3]}"
+
     def check_next_values(
             self,
             row: int,
